@@ -23,10 +23,16 @@ class ApplePayApi(BaseApi):
         This endpoint provides an easy way for platform developers to bulk
         activate
         Apple Pay on the Web with Square for merchants using their platform.
-        To learn more about Web Apple Pay, see
-        [Add the Apple Pay on the Web
-        Button](https://developer.squareup.com/docs/payment-form/add-digital-wa
-        llets/apple-pay).
+        Note: The SqPaymentForm library is deprecated as of May 13, 2021, and
+        will only receive critical security updates until it is retired on
+        October 31, 2022.
+        You must migrate your payment form code to the Web Payments SDK to
+        continue using your domain for Apple Pay. For more information on
+        migrating to the Web Payments SDK, see [Migrate to the Web Payments
+        SDK](https://developer.squareup.com/docs/web-payments/migrate).
+        To learn more about the Web Payments SDK and how to add Apple Pay, see
+        [Take an Apple Pay
+        Payment](https://developer.squareup.com/docs/web-payments/apple-pay).
 
         Args:
             body (RegisterDomainRequest): An object containing the fields to
