@@ -425,10 +425,9 @@ class CatalogApi(BaseApi):
                 request. Object types that are nested onto other object types
                 are not included in the defaults.  At the current API version
                 the default object types are: ITEM, CATEGORY, TAX, DISCOUNT,
-                MODIFIER_LIST, DINING_OPTION, TAX_EXEMPTION, SERVICE_CHARGE,
-                PRICING_RULE, PRODUCT_SET, TIME_PERIOD, MEASUREMENT_UNIT,
-                SUBSCRIPTION_PLAN, ITEM_OPTION, CUSTOM_ATTRIBUTE_DEFINITION,
-                QUICK_AMOUNT_SETTINGS.
+                MODIFIER_LIST,  PRICING_RULE, PRODUCT_SET, TIME_PERIOD,
+                MEASUREMENT_UNIT, SUBSCRIPTION_PLAN, ITEM_OPTION,
+                CUSTOM_ATTRIBUTE_DEFINITION, QUICK_AMOUNT_SETTINGS.
             catalog_version (long|int, optional): The specific version of the
                 catalog objects to be included in the response.  This allows
                 you to retrieve historical versions of objects. The specified
