@@ -4,15 +4,13 @@ from deprecation import deprecated
 from square.api_helper import APIHelper
 from square.http.api_response import ApiResponse
 from square.api.base_api import BaseApi
-from square.http.auth.o_auth_2 import OAuth2
 
 
 class InventoryApi(BaseApi):
 
     """A Controller to access Endpoints in the square API."""
-
-    def __init__(self, config, call_back=None):
-        super(InventoryApi, self).__init__(config, call_back)
+    def __init__(self, config, auth_managers):
+        super(InventoryApi, self).__init__(config, auth_managers)
 
     @deprecated()
     def deprecated_retrieve_inventory_adjustment(self,
@@ -21,7 +19,7 @@ class InventoryApi(BaseApi):
 
         Deprecated version of
         [RetrieveInventoryAdjustment]($e/Inventory/RetrieveInventoryAdjustment)
-        after the endpoint URL 
+        after the endpoint URL
         is updated to conform to the standard convention.
 
         Args:
@@ -56,7 +54,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.get(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -106,7 +106,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.get(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -124,7 +126,7 @@ class InventoryApi(BaseApi):
 
         Deprecated version of
         [BatchChangeInventory]($e/Inventory/BatchChangeInventory) after the
-        endpoint URL 
+        endpoint URL
         is updated to conform to the standard convention.
 
         Args:
@@ -158,7 +160,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -176,7 +180,7 @@ class InventoryApi(BaseApi):
 
         Deprecated version of
         [BatchRetrieveInventoryChanges]($e/Inventory/BatchRetrieveInventoryChan
-        ges) after the endpoint URL 
+        ges) after the endpoint URL
         is updated to conform to the standard convention.
 
         Args:
@@ -210,7 +214,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -228,7 +234,7 @@ class InventoryApi(BaseApi):
 
         Deprecated version of
         [BatchRetrieveInventoryCounts]($e/Inventory/BatchRetrieveInventoryCount
-        s) after the endpoint URL 
+        s) after the endpoint URL
         is updated to conform to the standard convention.
 
         Args:
@@ -262,7 +268,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -313,7 +321,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -367,7 +377,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -426,7 +438,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -444,7 +458,7 @@ class InventoryApi(BaseApi):
 
         Deprecated version of
         [RetrieveInventoryPhysicalCount]($e/Inventory/RetrieveInventoryPhysical
-        Count) after the endpoint URL 
+        Count) after the endpoint URL
         is updated to conform to the standard convention.
 
         Args:
@@ -480,7 +494,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.get(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -531,7 +547,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.get(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -581,7 +599,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.get(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -651,7 +671,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.get(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
@@ -671,17 +693,17 @@ class InventoryApi(BaseApi):
 
         Returns a set of physical counts and inventory adjustments for the
         provided [CatalogObject]($m/CatalogObject) at the requested
-        [Location]($m/Location)s. 
+        [Location]($m/Location)s.
         You can achieve the same result by calling
         [BatchRetrieveInventoryChanges]($e/Inventory/BatchRetrieveInventoryChan
-        ges) 
+        ges)
         and having the `catalog_object_ids` list contain a single element of
         the `CatalogObject` ID.
         Results are paginated and sorted in descending order according to
         their
         `occurred_at` timestamp (newest first).
         There are no limits on how far back the caller can page. This endpoint
-        can be 
+        can be
         used to display recent changes for a specific item. For more
         sophisticated queries, use a batch endpoint.
 
@@ -733,7 +755,9 @@ class InventoryApi(BaseApi):
 
         # Prepare and execute request
         _request = self.config.http_client.get(_query_url, headers=_headers)
-        OAuth2.apply(self.config, _request)
+        # Apply authentication scheme on request
+        self.apply_auth_schemes(_request, 'global')
+
         _response = self.execute_request(_request)
 
         decoded = APIHelper.json_deserialize(_response.text)
