@@ -194,8 +194,12 @@ class LoyaltyApi(BaseApi):
         from the loyalty program and
         loyalty promotion. For spend-based and visit-based programs, you can
         call [CalculateLoyaltyPoints]($e/Loyalty/CalculateLoyaltyPoints)
-        to compute the points earned from the loyalty program (but not points
-        earned from a loyalty promotion).
+        to compute the points earned from the base loyalty program. For
+        information about computing points earned from a loyalty promotion,
+        see
+        [Calculating promotion
+        points](https://developer.squareup.com/docs/loyalty-api/loyalty-promoti
+        ons#calculate-promotion-points).
 
         Args:
             account_id (string): The ID of the target [loyalty
