@@ -15,9 +15,8 @@ class TerminalApi(BaseApi):
                                body):
         """Does a POST request to /v2/terminals/actions.
 
-        Creates a Terminal action request and sends it to the specified device
-        to take a payment
-        for the requested amount.
+        Creates a Terminal action request and sends it to the specified
+        device.
 
         Args:
             body (CreateTerminalActionRequest): An object containing the
